@@ -16,8 +16,8 @@ def get_setting_value(name):
     return value
 
 
-def get_env_value(name):
-    value = os.environ.get(name)
+def get_env_value(name, default=None):
+    value = os.environ.get(name, default)
     if value is None:
         raise NotImplementedError("没有配置这个参数%s" % name)
     return value
