@@ -208,6 +208,8 @@ class AfterSaleType(object):
 
     # 特殊售后单快递转自提退运费
     AFSPLUS_REFUND_POSTAGE = "afsplus_refund_postage"
+    # 抖音生活退券售后
+    TIKAL = "tikal"
 
     CHOICES = (
         (NORMAL, "退货退款"),
@@ -220,6 +222,7 @@ class AfterSaleType(object):
         (OTHER, "其他"),
         (ONLY_REFUND, "仅退差价"),
         (AFSPLUS_REFUND_POSTAGE, "退运费"),
+        (TIKAL, "抖音生活退券"),
     )
 
 class AfterSaleReasons(object):
@@ -296,7 +299,7 @@ AFTERSALE_ALL_REASON_DICT = {
     AfterSaleReasons.EXCHANGE_PRODUCT_QUALITY_ISSUE:'换货：质量问题',
     AfterSaleReasons.RETURN_PRODUCT_QUALITY_ISSUE: '退货：质量问题',
     AfterSaleReasons.RETURN_PRODUCT_INAPPROPRIATE: '退货：穿着不合适需退货',
-    AfterSaleReasons.RETURN_PRODUCT_NOT_LIKE_OR_NOT_WANT: '退货：不喜欢，不想要了',
+    AfterSaleReasons.RETURN_PRODUCT_NOT_LIKE_OR_NOT_WANT: '商品缺货',
     AfterSaleReasons.RETURN_PRODUCT_DESCRIPTION_MISMATCH: '退货：商品与描述不符',
     AfterSaleReasons.CUSTOMER_NOT_WANT:"客人不想要了",
     AfterSaleReasons.PRODUCT_LACK_NO_WAIT: "商品缺货，不想等了",
@@ -326,9 +329,9 @@ AFTERSALE_ALL_REASON_DICT = {
 AFTERSALE_USER_REASON_LIST = [
     AfterSaleReasons.NOT_LIKE_OR_NOT_WANT,
     AfterSaleReasons.SHIPPING_TOO_SLOW_AND_NO_WAIT,
+    AfterSaleReasons.RETURN_PRODUCT_NOT_LIKE_OR_NOT_WANT,
     AfterSaleReasons.RETURN_PRODUCT_QUALITY_ISSUE,
     AfterSaleReasons.RETURN_PRODUCT_INAPPROPRIATE,
-    AfterSaleReasons.RETURN_PRODUCT_NOT_LIKE_OR_NOT_WANT,
     AfterSaleReasons.RETURN_PRODUCT_DESCRIPTION_MISMATCH,
     AfterSaleReasons.RETURN_POST,
     AfterSaleReasons.OTHER,
