@@ -10,7 +10,7 @@ from django.utils.functional import cached_property
 
 from ..core.constants import PayType
 from ..core.constants import ReturnQuantityType
-from ..core.constants import ShippingPartnerCodes_DICT
+from ..sparrow_shipping.constants import ShippingPartnerCodes
 from ..core.base_models import BaseModelTimeAndDeleted
 from ..core.model_function import get_object_or_None
 from ..core.common_utils import get_uuid4_hex
@@ -554,7 +554,7 @@ class Afs(BaseModelTimeAndDeleted):
                 #     continue
                 customer_express_code = afs_line.customer_express_code
                 afs_line_customer_express_name = afs_line.customer_express_name or ""
-                customer_express_name = ShippingPartnerCodes_DICT.get(customer_express_code, afs_line_customer_express_name)
+                customer_express_name = ShippingPartnerCodes.CODE_2_NAME_MAP.get(customer_express_code, afs_line_customer_express_name)
                 customer_shipping_number = afs_line.customer_shipping_number
 
                 if distribute_status in [DistributeStatus.PACKAGED,
