@@ -103,6 +103,11 @@ class DistributeStatus(object):
 
     # 2022.09 特需售后单自提转快递支付运费订单的发货单
     MAKEUP_POSTAGE_PAID = "paid"
+    
+    # 2023.4 退款单与发货单联动
+    # 退款单 售后仓已收 <> 售后仓已收
+    # event 售后仓入库
+    AFTERSALE_WH = "AftersaleWH"
 
     NO_SPLIT_STATUS_LIST = [
         INIT,
@@ -323,6 +328,7 @@ class DistributeStatus(object):
         (VIRTUAL_INIT, "虚拟商品初始态"),
         (CUS_CONFIRM_AT_VIRTUAL, "虚拟商品已提货"),
         (MAKEUP_POSTAGE_PAID, "运费已支付"),
+        (AFTERSALE_WH, "售后仓已收"),
     )
 
     DISTRIBUTE_STATUS_OWNER_DICT = {
@@ -456,6 +462,30 @@ class DistributeStatus(object):
         SPLIT,
     ]
 
+    # 未出汉光的发货单状态
+    DISTRIBUTE_STATUS_IN_HG_LIST = [
+        INIT,
+        PRINTED,
+        CUSSERVICE_PICKED_UP,
+        SERVICE_DESK,
+        SERVICE_STORE,
+        SPLIT,
+        OUTSTORAGE_WAIT_PACKAGE,
+        HGVENDING_INIT,
+        HGVENDING_WAIT_PICKUP,
+        TAILPAY_OVERTIME,
+        HAITAO_INIT,
+        HAITAO_BAISHI,
+        SERVICE_STOP,
+    ]
+
+    # 未出专柜
+    DISTRIBUTE_STATUS_IN_SHOP_LIST = [
+        INIT,
+        PRINTED,
+        OUTSTORAGE_WAIT_PACKAGE,
+    ]
+
 
 class __ShippingMethod(object):
     # 普通快递
@@ -596,32 +626,50 @@ class DistributeEventConst(object):
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
     
     CLOUDPRINT_SHIPPING_NUMBER = "cloudprint_shipping_number"
+    
+    # 2023.4 售后仓入库
+    ENTER_AFTERSALE_WH = 'enter_aftersale_wh'
+    # 2023.4 手动拆单
+    MANUAL_SPLIT = "manual_split"
 
     FROM_TO_MAP = {
         PRINT: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [DistributeStatus.INIT, DistributeStatus.PRINTED,
-                DistributeStatus.GUIDE_PICKED_UP, DistributeStatus.CUSSERVICE_PICKED_UP,
-                DistributeStatus.SERVICE_STORE, DistributeStatus.SERVICE_DESK,
-                DistributeStatus.PACKAGED, DistributeStatus.CUSSERVICE_HOLD,
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT,
+                DistributeStatus.PRINTED,
+                DistributeStatus.GUIDE_PICKED_UP,
+                DistributeStatus.CUSSERVICE_PICKED_UP,
+                DistributeStatus.SERVICE_STORE,
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.PACKAGED,
+                DistributeStatus.CUSSERVICE_HOLD,
                 DistributeStatus.CUS_CONFIRM,
                 DistributeStatus.CUS_CONFIRM_AT_GUIDE,
                 DistributeStatus.CUS_CONFIRM_AT_CUSSERVICE,
-                DistributeStatus.OUTSTORAGE_PACKAGED, DistributeStatus.OUTSTORAGE_WAIT_PACKAGE,
+                DistributeStatus.OUTSTORAGE_PACKAGED,
+                DistributeStatus.OUTSTORAGE_WAIT_PACKAGE,
                 DistributeStatus.SERVICE_STOP,
-                ],
+            ],
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
-                    DistributeStatus.INIT: DistributeStatus.PRINTED,
-                    },
+                DistributeStatus.INIT: DistributeStatus.PRINTED,
+            },
         },
         GUIDE_PRINT: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [DistributeStatus.INIT, DistributeStatus.PRINTED,
-                DistributeStatus.GUIDE_PICKED_UP],
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT,
+                DistributeStatus.PRINTED,
+                DistributeStatus.GUIDE_PICKED_UP
+            ],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.SPLIT
         },
         PRINT_AND_OVERWRITE_EXPRESS: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [DistributeStatus.INIT, DistributeStatus.PRINTED,
-                DistributeStatus.GUIDE_PICKED_UP, DistributeStatus.CUSSERVICE_PICKED_UP,
-                DistributeStatus.SERVICE_STORE, DistributeStatus.SERVICE_DESK,
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT,
+                DistributeStatus.PRINTED,
+                DistributeStatus.GUIDE_PICKED_UP,
+                DistributeStatus.CUSSERVICE_PICKED_UP,
+                DistributeStatus.SERVICE_STORE,
+                DistributeStatus.SERVICE_DESK,
                 DistributeStatus.CUSSERVICE_HOLD,
                 DistributeStatus.CUS_CONFIRM,
                 DistributeStatus.CUS_CONFIRM_AT_GUIDE,
@@ -630,17 +678,21 @@ class DistributeEventConst(object):
                 DistributeStatus.PACKAGED,
                 ],
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
-                    DistributeStatus.INIT: DistributeStatus.PRINTED,
-                    },
+                DistributeStatus.INIT: DistributeStatus.PRINTED,
+                },
         },
         CANCEL_PRINT: {
             DistributeEventConstKey.FROM_STATUS_LIST_KEY: [DistributeStatus.PRINTED],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.INIT,
         },
         CUSSERVICE_PICK_UP: {
-            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [DistributeStatus.INIT, DistributeStatus.PRINTED,
-                                DistributeStatus.SERVICE_DESK, DistributeStatus.SERVICE_STORE,
-                                DistributeStatus.SERVICE_STOP],
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT,
+                DistributeStatus.PRINTED,
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.SERVICE_STORE,
+                DistributeStatus.SERVICE_STOP
+                ],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.CUSSERVICE_PICKED_UP,
         },
         GUIDE_PICK_UP: {
@@ -750,10 +802,10 @@ class DistributeEventConst(object):
             DistributeEventConstKey.TO_STATE_MAP_KEY: {
                 DistributeStatus.INIT: DistributeStatus.SPLIT,
                 DistributeStatus.PRINTED: DistributeStatus.SPLIT,
-                DistributeStatus.CUSSERVICE_PICKED_UP: DistributeStatus.SPLIT,
+                DistributeStatus.CUSSERVICE_PICKED_UP: None,
                 DistributeStatus.GUIDE_PICKED_UP: DistributeStatus.SPLIT,
-                DistributeStatus.SERVICE_STORE: DistributeStatus.SPLIT,
-                DistributeStatus.SERVICE_DESK: DistributeStatus.SPLIT,
+                DistributeStatus.SERVICE_STORE: None,
+                DistributeStatus.SERVICE_DESK: None,
                 DistributeStatus.PACKAGED: None,
                 DistributeStatus.CUS_CONFIRM: None,
                 DistributeStatus.CUS_CONFIRM_AT_GUIDE: None,
@@ -767,7 +819,7 @@ class DistributeEventConst(object):
                 DistributeStatus.CUS_CONFIRM_AT_HGVENDING: None,
                 DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.DEPOSITPAY: None,
-                DistributeStatus.SERVICE_STOP: DistributeStatus.SPLIT,
+                DistributeStatus.SERVICE_STOP: None,
                 # DistributeStatus.HAITAO_INIT: None,
                 DistributeStatus.TAILPAY_OVERTIME: None,
                 DistributeStatus.MAKEUP_POSTAGE_PAID: None,
@@ -775,16 +827,23 @@ class DistributeEventConst(object):
         },
         CLOSE_AFTERSALE: {
             DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
-                DistributeStatus.CUSSERVICE_HOLD, DistributeStatus.PACKAGED,
                 DistributeStatus.CUS_CONFIRM,
                 DistributeStatus.CUS_CONFIRM_AT_GUIDE,
                 DistributeStatus.CUS_CONFIRM_AT_CUSSERVICE,
                 DistributeStatus.CUS_CONFIRM_AT_VIRTUAL,
-                DistributeStatus.CUSSERVICE_HOLD, DistributeStatus.PACKAGED, DistributeStatus.OUTSTORAGE_PACKAGED,
-                DistributeStatus.OUTSTORAGE_WAIT_PACKAGE, DistributeStatus.OUTSTORAGE_RETURN,
-                DistributeStatus.INIT, DistributeStatus.PRINTED, DistributeStatus.CUSSERVICE_PICKED_UP,
-                DistributeStatus.GUIDE_PICKED_UP, DistributeStatus.SERVICE_DESK, DistributeStatus.SERVICE_STORE,
-                DistributeStatus.HGVENDING_INIT, DistributeStatus.HGVENDING_WAIT_PICKUP,
+                DistributeStatus.CUSSERVICE_HOLD,
+                DistributeStatus.PACKAGED,
+                DistributeStatus.OUTSTORAGE_PACKAGED,
+                DistributeStatus.OUTSTORAGE_WAIT_PACKAGE,
+                DistributeStatus.OUTSTORAGE_RETURN,
+                DistributeStatus.INIT,
+                DistributeStatus.PRINTED,
+                DistributeStatus.CUSSERVICE_PICKED_UP,
+                DistributeStatus.GUIDE_PICKED_UP,
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.SERVICE_STORE,
+                DistributeStatus.HGVENDING_INIT,
+                DistributeStatus.HGVENDING_WAIT_PICKUP,
                 DistributeStatus.SERVICE_STOP,
                 DistributeStatus.DEPOSITPAY,
                 DistributeStatus.TAILPAY_OVERTIME,
@@ -868,7 +927,9 @@ class DistributeEventConst(object):
                                 DistributeStatus.CUSSERVICE_PICKED_UP,
                                 DistributeStatus.SERVICE_DESK,
                                 DistributeStatus.SERVICE_STORE,
-                                DistributeStatus.SERVICE_STOP],
+                                DistributeStatus.SERVICE_STOP,
+                                DistributeStatus.AFTERSALE_WH,
+                                ],
             DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.CUSSERVICE_HOLD,  # 客服已退
         },
         OUTSTORAGE_RETURN: {
@@ -1052,8 +1113,26 @@ class DistributeEventConst(object):
                 DistributeStatus.PACKAGED,
             ],
             DistributeEventConstKey.TO_STATUS_KEY: None
-        }
-
+        },
+        # 2023.4 售后仓入库 (位于客服处的发货单，可以执行售后仓入库)
+        ENTER_AFTERSALE_WH: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.CUSSERVICE_PICKED_UP,
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.SERVICE_STOP,
+                DistributeStatus.SERVICE_STORE,
+                ],
+            DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.AFTERSALE_WH,
+        },
+        MANUAL_SPLIT: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.CUSSERVICE_PICKED_UP,
+                DistributeStatus.SERVICE_DESK,
+                DistributeStatus.SERVICE_STOP,
+                DistributeStatus.SERVICE_STORE,
+                ],
+            DistributeEventConstKey.TO_STATUS_KEY: DistributeStatus.SPLIT,
+        },
     }
 
     EVENT_TO_BUTTONNAME_MAP = {
